@@ -4,7 +4,7 @@ import copy
 import math
 import pandas as pd
 import time
-from.function import keep_drop_judge
+from.function import is_number, col_is_number, keep_drop_judge
 
 # 最高10类数量占比
 top10_rate = 0.9
@@ -33,17 +33,6 @@ def is_meaningless(
         return False
 
 
-def is_number(s: str) -> bool:
-    """
-    判断字符是否为数字
-    """
-    try:
-        float(s)
-        return True
-    except ValueError:
-        return False
-
-
 def is_assets(data: pd.Series) -> bool:
     """
     大致判断字段是否为资产型字段
@@ -373,7 +362,7 @@ class DataPretreatment:
                 if is_continue:
                     continue
             judge = pd.value_counts(data[col]).iloc[:10].sum() / n
-            if is_number(str(data[col][data[col].first_valid_index()])):
+            if col_is_number(data, col):
                 if judge < top10_rate:
                     self.col_dict['num_col'].append(col)
                     continue
@@ -588,6 +577,8 @@ class DataPretreatment:
                 type_dict = {}
                 obj_list = []
                 for kind in unique_kind:
+                    if pd.isnull(kind):
+                        continue
                     if is_number(str(kind)):
                         type_dict[kind] = float(kind)
                     else:
