@@ -4,7 +4,7 @@ import pandas as pd
 import numpy as np
 import scipy.stats as st
 from sklearn.ensemble import RandomForestClassifier
-from .data_pretreatment import is_number
+from .data_pretreatment import col_is_number
 from .function import divide
 
 
@@ -17,7 +17,7 @@ max_type_num = 30
 def identify_col(data, col):
     n = data[col].count()
     judge = pd.value_counts(data[col]).iloc[:10].sum() / n
-    if is_number(str(data[col][data[col].first_valid_index()])):
+    if col_is_number(data, col):
         if judge < top10_rate:
             return 'num_col'
         judge2 = len(pd.value_counts(data[col]))
