@@ -1,6 +1,5 @@
 
 import time
-import sys
 import numpy as np
 from sklearn.model_selection import train_test_split
 import pandas as pd
@@ -15,7 +14,7 @@ except ImportError:
 # from .function import rfc_2d_section
 
 
-version = sys.version
+version = lgb.__version__
 model_name = {'RF': {'RFC', 'RF', 'rf', 'rfc', 'RandomForestClassifier'},
               'LGB': {'LGB', 'lgb', 'Lgb', 'lightgbm'},
               'XGB': {'XGB', 'xgb', 'xgboost'}}
@@ -90,7 +89,7 @@ def lgb_init(x_train, x_val, y_train, y_val, num_leaves, weight, epoch,
                 return 'f1_score', f1_score(pre, labels), True
         else:
             lgb_evaluate_func = evaluate_func
-        if version >= '3.8':
+        if version >= '3.3.0':
             callbacks = [lgb.early_stopping(early_stopping), lgb.log_evaluation(1, show_stdv=False)]
             model = lgb.train(lgb_params, train_data, epoch, valid_sets=[train_data, val_data],
                               feval=lgb_evaluate_func, callbacks=callbacks)
@@ -98,7 +97,7 @@ def lgb_init(x_train, x_val, y_train, y_val, num_leaves, weight, epoch,
             model = lgb.train(lgb_params, train_data, epoch, valid_sets=[train_data, val_data],
                               feval=lgb_evaluate_func, early_stopping_rounds=early_stopping, verbose_eval=False)
     else:
-        if version >= '3.8':
+        if version >= '3.3.0':
             callbacks = [lgb.early_stopping(early_stopping), lgb.log_evaluation(1, show_stdv=False)]
             model = lgb.train(lgb_params, train_data, epoch, valid_sets=[train_data, val_data],
                               callbacks=callbacks)
@@ -465,7 +464,7 @@ class ModelBuild:
                     return 'f1_score', f1_score(pre, labels), True
             else:
                 lgb_evaluate_func = self.evaluate_func
-            if version >= '3.8':
+            if version >= '3.3.0':
                 callbacks = [lgb.early_stopping(self.early_stopping), lgb.log_evaluation(self.verbose)]
                 model = lgb.train(lgb_params, train_data, self.epoch, valid_sets=[train_data, val_data],
                                   feval=lgb_evaluate_func, callbacks=callbacks)
@@ -474,7 +473,7 @@ class ModelBuild:
                                   feval=lgb_evaluate_func, early_stopping_rounds=self.early_stopping,
                                   verbose_eval=self.verbose)
         else:
-            if version >= '3.8':
+            if version >= '3.3.0':
                 callbacks = [lgb.early_stopping(self.early_stopping), lgb.log_evaluation(self.verbose)]
                 model = lgb.train(lgb_params, train_data, self.epoch, valid_sets=[train_data, val_data],
                                   callbacks=callbacks)
